pub struct ContextCompactor { /* private fields */ }Expand description
Manages context compaction for conversation history
Implementations
Sourceimpl ContextCompactor
impl ContextCompactor
Sourcepub fn new(config: CompactionConfig) -> Self
pub fn new(config: CompactionConfig) -> Self
Create a new context compactor with the given configuration
Sourcepub fn with_max_tokens(max_tokens: usize) -> Self
pub fn with_max_tokens(max_tokens: usize) -> Self
Create with default config for a specific max token limit
Sourcepub fn needs_compaction(&self, current_tokens: usize) -> bool
pub fn needs_compaction(&self, current_tokens: usize) -> bool
Check if compaction is needed based on current token count
Sourcepub fn approaching_limit(&self, current_tokens: usize) -> bool
pub fn approaching_limit(&self, current_tokens: usize) -> bool
Check if we’re approaching the limit (warning threshold at 90%)
Sourcepub fn estimate_total_tokens(messages: &[Message]) -> usize
pub fn estimate_total_tokens(messages: &[Message]) -> usize
Estimate total tokens for a list of messages
Sourcepub fn compact(&self, messages: &[Message]) -> CompactionResult
pub fn compact(&self, messages: &[Message]) -> CompactionResult
Compact messages to fit within token limit
Sourcepub fn compact_messages(
&self,
messages: Vec<Message>,
) -> (Vec<Message>, CompactionResult)
pub fn compact_messages( &self, messages: Vec<Message>, ) -> (Vec<Message>, CompactionResult)
Compact messages and return the compacted list
Sourcepub fn config(&self) -> &CompactionConfig
pub fn config(&self) -> &CompactionConfig
Get the current configuration